#!/bin/sh

#
# ActivePerl Installer
#
# (c) 2000-2001, ActiveState Tool Corp.  All rights reserved.
#

# Find out how to echo without newlines.
(echo "howdy\c"; echo " ") > /tmp/.echotmp
if grep c /tmp/.echotmp >/dev/null 2>&1 ; then
n='-n'
c=''
else
n=''
c='\c'
fi
rm -f /tmp/.echotmp

# Write ourselves a portable 'mkdir -p':
MAKEDIR=/tmp/makedir.sh
cat >$MAKEDIR <<'EOM'
#!/bin/sh
# makedir.SH
# 

export PATH || (echo "OOPS, this isn't sh.  Desperation time.  I will feed myself to sh."; sh $0; kill $$)

case $# in
  0)
    echo "makedir pathname filenameflag"
    exit 1
    ;;
esac

: guarantee one slash before 1st component
case $1 in
  /*) ;;
  *)  set ./$1 $2 ;;
esac

: strip last component if it is to be a filename
case X$2 in
  X1) set `echo $1 | sed 's:\(.*\)/[^/]*$:\1:'` ;;
  *)  set $1 ;;
esac

: return reasonable status if nothing to be created
if test -d "$1" ; then
    exit 0
fi

list=''
while true ; do
    case $1 in
    */*)
	list="$1 $list"
	set `echo $1 | sed 's:\(.*\)/:\1 :'`
	;;
    *)
	break
	;;
    esac
done

set $list

for dir do
    mkdir $dir >/dev/null 2>&1
done

EOM
chmod 755 $MAKEDIR

platform=perl

cat <<EOM

    Welcome to ActivePerl.

    This installer can install ActivePerl in any location of your choice.
    You do not need root privileges.  However, please make sure that you
    have write access to this location.

EOM

echo $n "Enter top level directory for install [/usr/local/ActivePerl-5.6] $c"
read whereto
if test "X$whereto" = "X"; then
whereto="/usr/local/ActivePerl-5.6"
fi

if test -f "$whereto" || test -d "$whereto" ; then
cat <<EOM

$whereto appears to already exist.

    WARNING: Install may fail if any existing files cannot be
    overwritten.

EOM
else
cat <<EOM
Installing to $whereto.
EOM
fi

# Print a little blurb about PPM and Profiles
cat <<EOM

    ActivePerl includes Programmer's Package Manager version 3, which
    includes many improvements.

    One of these enhancements enables you to keep track of your installed
    packages through the PPM Profiles functionality.  PPM will automatically
    communicate your package installs and updates securely and transparently
    to your ASPN Profile.  Such saved Profiles are useful for various
    purposes, including tracking, migrating, reinstalling, upgrading, or
    restoring PPM packages in one or more locations.

    Using the profile functionality requires installing a license for
    ASPN Perl.  You can always disable or enable the Profile feature later
    within PPM3.

	More About ASPN Perl:
	http://www.ActiveState.com/Products/ASPN_Perl/

	ActiveState's Privacy Policy:
	http://www.ActiveState.com/ASPN/Legal/Privacy

EOM

echo $n "Enable PPM3 to send profile info to ASPN? [n] $c"
read ans
case "$ans" in
    [Yy]*)
	cat <<EOM
Enabling the Profile feature. PPM3 will set up a default profile the first
time it is run.
EOM
	ppm3_profiles=1
    ;;
    *)
	cat <<EOM
Disabling the Profile feature.  PPM Profiles can be enabled later by typing
'set profile-track=1' inside PPM3.
EOM
	ppm3_profiles=0
    ;;
esac

cat <<EOM

    The typical ActivePerl software installation requires 55 megabytes.
    Please make sure enough free space is available before continuing.

EOM

echo $n "Proceed? [y] $c"
read ans
case "$ans" in
    [Nn]*)
    echo "Bailing out..."
    rm -f $MAKEDIR
    exit 1
    ;;
    *)
    echo "Continuing..."
    ;;
esac

topdir=`pwd`
apfrom="$topdir/$platform"
spongedir=".TheInstallScriptWasNotRunTheInstallScriptWasNotRunTheInstallScriptWasNotRun-perl"
wherefrom="/tmp/$spongedir"

help_blurb () {
cat <<EOM

    If you had any problems with the installation process, please report
    them to the ActivePerl bug database, available online:

        http://bugs.ActiveState.com/ActivePerl/
    
    For general questions or comments about ActivePerl, please contact us
    at support@ActiveState.com.

EOM
}

#
# Set up links for accessing perl from the local dir.
echo "Setting up links"
rm -rf $wherefrom

if ln -s $apfrom $wherefrom; then
    echo "Installing ActivePerl, please wait..."
    PERL="$wherefrom/bin/perl"

    # Relocate the Perl tree wholesale.
    if $PERL $wherefrom/bin/reloc_perl $whereto $wherefrom; then

	# Configure PPM3
	$whereto/bin/ppm3 set profile-track $ppm3_profiles > /dev/null

	# generate the HTML documentation
	echo "Generating HTML documentation, this may take several minutes..."
	$whereto/bin/perl -MActivePerl::DocTools -e 'UpdateHTML(1)'

	# Make the new perl the default.
	cat <<EOM

    Perl has been succesfully installed at $whereto.

    Please modify your startup environment by adding:

	$whereto/bin to PATH
	$whereto/man to MANPATH
EOM
	help_blurb
    else
	echo ""
	echo "    Install failed, unable to relocate perl!"
	help_blurb
	rm -f $MAKEDIR
	rm -f $wherefrom
	exit 1
    fi
    rm -f $wherefrom
else
    echo ""
    echo "    Install failed, unable to set up links!"
    help_blurb
    rm -f $MAKEDIR
    exit 1
fi

rm -f $MAKEDIR
